package com.example.firebasesdkexample2;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.ActionCodeSettings;
import com.google.firebase.auth.AuthResult;
import com.google.firebase.auth.FirebaseAuth;

public class MainActivity extends AppCompatActivity {
    private EditText email;
    private Button signin;
    private String email_address, email_link,pending_email;

    String TAG="EMAIL_AUTH";

    FirebaseAuth auth;

    private SharedPreferences pref;

    private static final String KEY_PENDING_EMAIL="key_pending_email";
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        email=(EditText)findViewById(R.id.editText);
        signin=(Button)findViewById(R.id.SignInButton);
        signin.setEnabled(false);

        auth=FirebaseAuth.getInstance();

        pref=getApplicationContext().getSharedPreferences("MyPref", Context.MODE_PRIVATE);
        pending_email=pref.getString(KEY_PENDING_EMAIL,null);

        if(pending_email!=null){
            email.setText(pending_email);
            Log.d(TAG,"Getting Shared Preferences"+pending_email);
        }
        Intent intent = getIntent();
        if (intent != null && intent.getData() != null) {
            email_link = intent.getData().toString();
            Log.d(TAG, "got an intent: " + email_link);

            // Confirm the link is a sign-in with email link.
            if (auth.isSignInWithEmailLink(email_link)) {
                signin.setEnabled(true);
            }
        }
    }

    public void onSignInClickedButton(View view) {
        email_address = email.getText().toString();

        auth.signInWithEmailLink(email_address, email_link)
                .addOnCompleteListener(new OnCompleteListener<AuthResult>() {
                    @Override
                    public void onComplete(@NonNull Task<AuthResult> task) {

                        // remove shared preferences, set everything back to default
                        pending_email = null;
                        SharedPreferences.Editor editor = pref.edit();
                        editor.remove(KEY_PENDING_EMAIL);
                        editor.commit();
                        email.setText("");

                        if (task.isSuccessful()) {
                            Toast.makeText(getApplicationContext(), "Successfully signed in with email link!", Toast.LENGTH_SHORT).show();
                            AuthResult result = task.getResult();
                        } else {
                            Toast.makeText(getApplicationContext(), "Error signing in with email link", Toast.LENGTH_SHORT).show();
                        }
                    }
                });
    }

    public void onEmailClick(View view) {
        email_address = email.getText().toString();
        if (email_address.equals("")) {
            Toast.makeText(getApplicationContext(), "Enter Email Address!", Toast.LENGTH_SHORT).show();
            return;
        }
        //Save Email Address
        SharedPreferences.Editor editor=pref.edit();
        editor.putString(KEY_PENDING_EMAIL,email_address);
        editor.commit();

        ActionCodeSettings actionCodeSettings = ActionCodeSettings.newBuilder()
                .setAndroidPackageName(
                        getPackageName(),
                        false, /* install if not available? */
                        null   /* minimum app version */)
                .setHandleCodeInApp(true)
                .setUrl("https://auth.example.com/emailSignInLink")
                .build();

        auth.sendSignInLinkToEmail(email_address, actionCodeSettings)
                .addOnCompleteListener(new OnCompleteListener<Void>() {
                    @Override
                    public void onComplete(@NonNull Task<Void> task) {
                        if (task.isSuccessful()) {
                            Toast.makeText(getApplicationContext(), "Email Sent", Toast.LENGTH_LONG).show();
                        }
                    }
                });
    }
}
